/*
 * Copyright 2012-2017 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.gateway.common.core.auth;

import java.util.Collections;
import java.util.Objects;
import java.util.Set;

public class Role {
    public static final String ACTION_DELIMITER = ",";
    public static final String ROLE_DELIMITER = "-";
    /**
     * Array of regex that valid roles cannot match
     * Role cannot contain any whitespaces
     */
    public static final String[] RESTRICTED_CHARACTERS_REGEX = new String[]{".*\\s+.*"};

    private final Set<String> actions;
    private final String realm;

    public Role(Set<String> actions, String realm) {
        Objects.requireNonNull(actions);
        Objects.requireNonNull(realm);
        this.actions = Collections.unmodifiableSet(actions);
        this.realm = realm;
    }

    public Set<String> getActions() {
        return this.actions;
    }

    public String getRealm() {
        return this.realm;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        Role role = (Role) o;

        if (!actions.equals(role.actions)) {
            return false;
        }

        return realm.equals(role.realm);
    }

    public boolean containsAction(String action) {
        return this.actions.contains(action);
    }

    @Override
    public int hashCode() {
        return Objects.hash(actions, realm);
    }
}
